"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createGenericLogger = void 0;
const mongodb_log_writer_1 = require("mongodb-log-writer");
const debug_1 = __importDefault(require("debug"));
function createGenericLogger(component, emit) {
    // Do not create an actual Writable stream here, since the callback
    // logic in Node.js streams would mean that two writes from the
    // same event loop tick would not be written synchronously,
    // allowing another logger's write to be written out-of-order.
    const target = {
        write(line, callback) {
            emit('compass:log', { line });
            callback();
        },
        end(callback) {
            callback();
        },
    };
    const writer = new mongodb_log_writer_1.MongoLogWriter('', null, target);
    const log = writer.bindComponent(component);
    const debug = (0, debug_1.default)(`mongodb-compass:${component.toLowerCase()}`);
    writer.on('log', ({ s, ctx, msg, attr }) => {
        if (attr) {
            debug(msg, { s, ctx, ...attr });
        }
        else {
            debug(msg, { s, ctx });
        }
    });
    return {
        log,
        mongoLogId: mongodb_log_writer_1.mongoLogId,
        debug,
    };
}
exports.createGenericLogger = createGenericLogger;
//# sourceMappingURL=logger.js.map